@@ -30,23 +30,18 @@ cmap: str = "gray"):
     plt.close()
     return my_base64_jpgData
 
-#def exit_handler():
-#    logging.info('VSUI exit handler triggered')
-#    disconnect()
+def exit_handler():
+    logging.info('VSUI exit handler triggered')
+    disconnect()
                     
 # https://stackoverflow.com/a/51981833
 def vsui_process():
     def decorator(func):
         def wrapper(*args, **kwargs):
             r = None
-            try:
-                #atexit.register(exit_handler)
-                r = func(*args, **kwargs)
-            except Exception as e:
-                disconnect()
-                logging.error(e)
-            finally:
-                return r
+            atexit.register(exit_handler)
+            r = func(*args, **kwargs)
+            return r
         return wrapper
     return decorator
 
